pub struct DependabotAlertSecurityAdvisory<'a> {Show 13 fields
pub ghsa_id: &'a str,
pub cve_id: Option<&'a str>,
pub summary: &'a str,
pub description: &'a str,
pub vulnerabilities: Vec<DependabotAlertSecurityAdvisoryVulnerabilities<'a>>,
pub severity: DependabotAlertSecurityAdvisorySeverity,
pub cvss: SecurityAdvisoryCvss<'a>,
pub cwes: Vec<SecurityAdvisoryCwes<'a>>,
pub identifiers: Vec<DependabotAlertSecurityAdvisoryIdentifiers<'a>>,
pub references: Vec<DependabotAlertSecurityAdvisoryReferences<'a>>,
pub published_at: &'a str,
pub updated_at: &'a str,
pub withdrawn_at: Option<&'a str>,
}Fields
ghsa_id: &'a strDetails for the GitHub Security Advisory.
cve_id: Option<&'a str>The unique CVE ID assigned to the advisory.
summary: &'a strA short, plain text summary of the advisory.
description: &'a strA long-form Markdown-supported description of the advisory.
vulnerabilities: Vec<DependabotAlertSecurityAdvisoryVulnerabilities<'a>>Vulnerable version range information for the advisory.
severity: DependabotAlertSecurityAdvisorySeverityThe severity of the advisory.
cvss: SecurityAdvisoryCvss<'a>cwes: Vec<SecurityAdvisoryCwes<'a>>Details for the advisory pertaining to Common Weakness Enumeration.
identifiers: Vec<DependabotAlertSecurityAdvisoryIdentifiers<'a>>Values that identify this advisory among security information sources.
references: Vec<DependabotAlertSecurityAdvisoryReferences<'a>>Links to additional advisory information.
published_at: &'a strThe time that the advisory was published in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
updated_at: &'a strThe time that the advisory was last modified in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
withdrawn_at: Option<&'a str>The time that the advisory was withdrawn in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.